==> node-make-0.0.11.tgz: package/index.js <==
'use strict';

var _createClass = require('babel-runtime/helpers/create-class');
_createClass = 'default' in _createClass ? _createClass['default'] : _createClass;
var _classCallCheck = require('babel-runtime/helpers/class-call-check');
_classCallCheck = 'default' in _classCallCheck ? _classCallCheck['default'] : _classCallCheck;
var _asyncToGenerator = require('babel-runtime/helpers/async-to-generator');
_asyncToGenerator = 'default' in _asyncToGenerator ? _asyncToGenerator['default'] : _asyncToGenerator;
var nfs = require('fs');
nfs = 'default' in nfs ? nfs['default'] : nfs;
var pathExists = require('path-exists');
pathExists = 'default' in pathExists ? pathExists['default'] : pathExists;
var pify = require('pify');
pify = 'default' in pify ? pify['default'] : pify;
var _getIterator = require('babel-runtime/core-js/get-iterator');
_getIterator = 'default' in _getIterator ? _getIterator['default'] : _getIterator;
var path = require('path');
path = 'default' in path ? path['default'] : path;
var _slicedToArray = require('babel-runtime/helpers/sliced-to-array');
_slicedToArray = 'default' in _slicedToArray ? _slicedToArray['default'] : _slicedToArray;
var babel = require('babel-core');
babel = 'default' in babel ? babel['default'] : babel;
var requireFromString = require('require-from-string');
requireFromString = 'default' in requireFromString ? requireFromString['default'] : requireFromString;
var O = require('orchestrator');
O = 'default' in O ? O['default'] : O;
var prettyHrtime = require('pretty-hrtime');
prettyHrtime = 'default' in prettyHrtime ? prettyHrtime['default'] : prettyHrtime;

var babelHelpers = {};

babelHelpers.createClass = (function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
})();

babelHelpers.slicedToArray = (function () {
  function sliceIterator(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;

    try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"]) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  return function (arr, i) {
    if (Array.isArray(arr)) {
      return arr;
    } else if (Symbol.iterator in Object(arr)) {
      return sliceIterator(arr, i);
    } else {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }
  };
})();

babelHelpers.asyncToGenerator = function (fn) {
  return function () {
    var gen = fn.apply(this, arguments);
    return new Promise(function (resolve, reject) {
      var callNext = step.bind(null, "next");
      var callThrow = step.bind(null, "throw");

      function step(key, arg) {
        try {
          var info = gen[key](arg);
          var value = info.value;
        } catch (error) {
          reject(error);
          return;
        }

        if (info.done) {
          resolve(value);
        } else {
          Promise.resolve(value).then(callNext, callThrow);
        }
      }

      callNext();
    });
  };
};

babelHelpers.classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};
var o = new O();

o.on('task_start', function (e) {
  log('Starting', ('\'' + e.task + '\'').cyan, '...');
});
o.on('task_stop', function (e) {
  log('Finished', ('\'' + e.task + '\'').cyan, 'in ' + prettyHrtime(e.hrDuration));
});

function addTasks(tasks) {
  for (var task in tasks) {
    if (typeof tasks[task] === 'function') {
      o.add(task, tasks[task]);
    }
  }
}

function startTask(task) {
  o.start(task, function (err) {
    if (err) {
      if (err.missingTask) {
        log(('Task \'' + err.missingTask + '\' not found').red);
      } else {
        console.log(err);
      }
    }
  });
}

var fs = pify(nfs);
var exists = pify(pathExists);

var getFileByOrder = _asyncToGenerator(function* () {
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _len = arguments.length, files = Array(_len), _key = 0; _key < _len; _key++) {
      files[_key] = arguments[_key];
    }

    for (var _iterator = _getIterator(files), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var file = _step.value;

      if (exists(file)) {
        var data = {
          name: file,
          value: yield fs.readFile(file, 'utf8')['catch'](function (err) {
            return console.log(err.stack);
          })
        };
        return data;
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator['return']) {
        _iterator['return']();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }
});

var getConfigFile = _asyncToGenerator(function* () {
  var customFile = arguments.length <= 0 || arguments[0] === undefined ? joinCurrentDir('makefile.js') : arguments[0];

  return yield getFileByOrder(customFile, joinCurrentDir('mk.js'))['catch'](function (err) {
    return console.log(err.stack);
  });
});

function joinCurrentDir(filePath) {
  return filePath ? path.join(process.cwd(), filePath) : null;
}

var RE_MATCH_TASKS = /(\r?\n){2,}/;
var RE_MATCH_LINES = /\r?\n{1,}/;
var RE_MATCH_INTRO = /^(\w+)\:\s*([a-zA-Z0-9\.\/]*)/;
var RE_MATCH_IMPORT_INTRO = /^\@import\:\s*/;

var transformOptions = {
  blacklist: ['regenerator'],
  optional: ['asyncToGenerator', 'runtime'],
  loose: ['es6.modules']
};
function parser(string) {
  if (typeof string !== 'string') {
    throw new Error('Input is not string!');
  }
  var code = undefined;
  try {
    string = string.split(RE_MATCH_TASKS).filter(function (s) {
      return !!s.replace(/\s+/g, '');
    });
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = _getIterator(string.entries()), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var _step$value = _slicedToArray(_step.value, 2);

        var i = _step$value[0];
        var s = _step$value[1];

        var lines = s.split(RE_MATCH_LINES).filter(function (line) {
          return !!line.replace(/\s+/g, '');
        });
        var intro = lines[0];
        if (RE_MATCH_INTRO.test(intro)) {
          var _intro$match = intro.match(RE_MATCH_INTRO);

          var _intro$match2 = _slicedToArray(_intro$match, 3);

          var taskName = _intro$match2[1];
          var externalFile = _intro$match2[2];

          if (externalFile) {
            (function () {
              var tempLines = [];
              lines.forEach(function (intro) {
                var _intro$match3 = intro.match(RE_MATCH_INTRO);

                var _intro$match32 = _slicedToArray(_intro$match3, 3);

                var taskName = _intro$match32[1];
                var externalFile = _intro$match32[2];

                var taskContent = nfs.readFileSync(joinCurrentDir(externalFile), 'utf8');
                tempLines.push('export const ' + taskName + ' = () => {\n              ' + taskContent + '\n            }');
              });
              lines = tempLines.join('\n');
            })();
          } else {
            // match taskName, externalFile from line one
            // prepend to function heading
            lines[0] = 'export const ' + taskName + ' = () => {';
            // append `}` to function ending
            lines.push('}');
            lines = lines.join('\n');
          }
          string[i] = lines;
        } else if (RE_MATCH_IMPORT_INTRO.test(intro)) {
          lines.shift(0);
          string[i] = lines.join('\n');
        }
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator['return']) {
          _iterator['return']();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    code = babel.transform(string.join('\n\n'), transformOptions).code;
  } catch (err) {
    console.log(err.stack);
  }
  return requireFromString(code);
}

var Make = (function () {
  function Make() {
    _classCallCheck(this, Make);

    this.requireMakeFile();
  }

  _createClass(Make, [{
    key: 'requireMakeFile',
    value: _asyncToGenerator(function* () {
      var file = yield getConfigFile(argv.c || argv.config)['catch'](function (err) {
        return console.log(err.stack);
      });
      this.runTask(parser(file.value));
    })
  }, {
    key: 'runTask',
    value: function runTask(tasks) {
      addTasks(tasks);
      var taskName = argv._[0] || 'default';
      startTask(taskName);
    }
  }]);

  return Make;
})();

function make() {
  return new Make();
}

module.exports = make;

==> node-make-0.0.12.tgz: package/index.js <==
'use strict';

var _createClass = require('babel-runtime/helpers/create-class');
_createClass = 'default' in _createClass ? _createClass['default'] : _createClass;
var _classCallCheck = require('babel-runtime/helpers/class-call-check');
_classCallCheck = 'default' in _classCallCheck ? _classCallCheck['default'] : _classCallCheck;
var _asyncToGenerator = require('babel-runtime/helpers/async-to-generator');
_asyncToGenerator = 'default' in _asyncToGenerator ? _asyncToGenerator['default'] : _asyncToGenerator;
var nfs = require('fs');
nfs = 'default' in nfs ? nfs['default'] : nfs;
var pathExists = require('path-exists');
pathExists = 'default' in pathExists ? pathExists['default'] : pathExists;
var pify = require('pify');
pify = 'default' in pify ? pify['default'] : pify;
var _getIterator = require('babel-runtime/core-js/get-iterator');
_getIterator = 'default' in _getIterator ? _getIterator['default'] : _getIterator;
var path = require('path');
path = 'default' in path ? path['default'] : path;
var _slicedToArray = require('babel-runtime/helpers/sliced-to-array');
_slicedToArray = 'default' in _slicedToArray ? _slicedToArray['default'] : _slicedToArray;
var babel = require('babel-core');
babel = 'default' in babel ? babel['default'] : babel;
var requireFromString = require('require-from-string');
requireFromString = 'default' in requireFromString ? requireFromString['default'] : requireFromString;
var O = require('orchestrator');
O = 'default' in O ? O['default'] : O;
var prettyHrtime = require('pretty-hrtime');
prettyHrtime = 'default' in prettyHrtime ? prettyHrtime['default'] : prettyHrtime;

var babelHelpers = {};

babelHelpers.createClass = (function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
})();

babelHelpers.slicedToArray = (function () {
  function sliceIterator(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;

    try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"]) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  return function (arr, i) {
    if (Array.isArray(arr)) {
      return arr;
    } else if (Symbol.iterator in Object(arr)) {
      return sliceIterator(arr, i);
    } else {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }
  };
})();

babelHelpers.asyncToGenerator = function (fn) {
  return function () {
    var gen = fn.apply(this, arguments);
    return new Promise(function (resolve, reject) {
      var callNext = step.bind(null, "next");
      var callThrow = step.bind(null, "throw");

      function step(key, arg) {
        try {
          var info = gen[key](arg);
          var value = info.value;
        } catch (error) {
          reject(error);
          return;
        }

        if (info.done) {
          resolve(value);
        } else {
          Promise.resolve(value).then(callNext, callThrow);
        }
      }

      callNext();
    });
  };
};

babelHelpers.classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};
var o = new O();

o.on('task_start', function (e) {
  log('Starting', ('\'' + e.task + '\'').cyan, '...');
});
o.on('task_stop', function (e) {
  log('Finished', ('\'' + e.task + '\'').cyan, 'in ' + prettyHrtime(e.hrDuration));
});

function addTasks(tasks) {
  for (var task in tasks) {
    if (typeof tasks[task] === 'function') {
      o.add(task.substring(2), tasks[task]);
    }
  }
}

function startTask(task) {
  o.start(task, function (err) {
    if (err) {
      if (err.missingTask) {
        log(('Task \'' + err.missingTask + '\' not found').red);
      } else {
        console.log(err);
      }
    }
  });
}

var fs = pify(nfs);
var exists = pify(pathExists);

var getFileByOrder = _asyncToGenerator(function* () {
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _len = arguments.length, files = Array(_len), _key = 0; _key < _len; _key++) {
      files[_key] = arguments[_key];
    }

    for (var _iterator = _getIterator(files), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var file = _step.value;

      if (exists(file)) {
        var data = {
          name: file,
          value: yield fs.readFile(file, 'utf8')['catch'](function (err) {
            return console.log(err.stack);
          })
        };
        return data;
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator['return']) {
        _iterator['return']();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }
});

var getConfigFile = _asyncToGenerator(function* () {
  var customFile = arguments.length <= 0 || arguments[0] === undefined ? joinCurrentDir('makefile.js') : arguments[0];

  return yield getFileByOrder(customFile, joinCurrentDir('mk.js'))['catch'](function (err) {
    return console.log(err.stack);
  });
});

function joinCurrentDir(filePath) {
  return filePath ? path.join(process.cwd(), filePath) : null;
}

var RE_MATCH_TASKS = /(\r?\n){2,}/;
var RE_MATCH_LINES = /\r?\n{1,}/;
var RE_MATCH_INTRO = /^(\w+)\:\s*([a-zA-Z0-9\.\/]*)/;
var RE_MATCH_IMPORT_INTRO = /^\@import\:\s*/;

var transformOptions = {
  blacklist: ['regenerator'],
  optional: ['asyncToGenerator', 'runtime'],
  loose: ['es6.modules']
};
function parser(string) {
  if (typeof string !== 'string') {
    throw new Error('Input is not string!');
  }
  var code = undefined;
  try {
    string = string.split(RE_MATCH_TASKS).filter(function (s) {
      return !!s.replace(/\s+/g, '');
    });
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = _getIterator(string.entries()), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var _step$value = _slicedToArray(_step.value, 2);

        var i = _step$value[0];
        var s = _step$value[1];

        var lines = s.split(RE_MATCH_LINES).filter(function (line) {
          return !!line.replace(/\s+/g, '');
        });
        var intro = lines[0];
        if (RE_MATCH_INTRO.test(intro)) {
          var _intro$match = intro.match(RE_MATCH_INTRO);

          var _intro$match2 = _slicedToArray(_intro$match, 3);

          var taskName = _intro$match2[1];
          var externalFile = _intro$match2[2];

          if (externalFile) {
            (function () {
              var tempLines = [];
              lines.forEach(function (intro) {
                var _intro$match3 = intro.match(RE_MATCH_INTRO);

                var _intro$match32 = _slicedToArray(_intro$match3, 3);

                var taskName = _intro$match32[1];
                var externalFile = _intro$match32[2];

                var taskContent = nfs.readFileSync(joinCurrentDir(externalFile), 'utf8');
                tempLines.push('export const __' + taskName + ' = () => {\n              ' + taskContent + '\n            }');
              });
              lines = tempLines.join('\n');
            })();
          } else {
            // match taskName, externalFile from line one
            // prepend to function heading
            lines[0] = 'export const __' + taskName + ' = () => {';
            // append `}` to function ending
            lines.push('}');
            lines = lines.join('\n');
          }
          string[i] = lines;
        } else if (RE_MATCH_IMPORT_INTRO.test(intro)) {
          lines.shift(0);
          string[i] = lines.join('\n');
        }
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator['return']) {
          _iterator['return']();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    code = babel.transform(string.join('\n\n'), transformOptions).code;
  } catch (err) {
    console.log(err.stack);
  }
  return requireFromString(code);
}

var Make = (function () {
  function Make() {
    _classCallCheck(this, Make);

    this.requireMakeFile();
  }

  _createClass(Make, [{
    key: 'requireMakeFile',
    value: _asyncToGenerator(function* () {
      var file = yield getConfigFile(argv.c || argv.config)['catch'](function (err) {
        return console.log(err.stack);
      });
      this.runTask(parser(file.value));
    })
  }, {
    key: 'runTask',
    value: function runTask(tasks) {
      addTasks(tasks);
      var taskName = argv._[0] || 'default';
      startTask(taskName);
    }
  }]);

  return Make;
})();

function make() {
  return new Make();
}

module.exports = make;
